@@ -1,5 +1,5 @@
 package IRC::Toolkit::Masks;
-$IRC::Toolkit::Masks::VERSION = '0.090003';
+$IRC::Toolkit::Masks::VERSION = '0.091001';
 use Carp;
 use strictures 2;
 
@@ -36,23 +36,25 @@ sub normalize_mask {
   $orig =~ s/\*{2,}/*/g;
 
   my ($piece, @mask);
-  ## nick, if we have one, or * if we don't.
   if ( index($orig, '!') == -1 && index($orig, '@') > -1) {
+    # no nick, add '*'
     $piece = $orig;
-    push @mask, '*';
+    @mask  = '*';
   } else {
     ($mask[0], $piece) = split /!/, $orig, 2;
   }
 
-  ## user/host portions
+  ## user/host
   if (defined $piece) {
     $piece      =~ s/!//g;
     @mask[1, 2] = split /@/, $piece, 2;
   }
+  $mask[2] =~ s/@//g if defined $mask[2];
 
   $mask[0] 
-  . '!' . (defined $mask[1] ? $mask[1] : '*' )
-  . '@' . (defined $mask[2] ? ($mask[2] =~ s/@//g, $mask[2]) : '*' )
+  # defined+length is annoying but elsewise we get fatal warnings on 5.10
+  . '!' . (defined $mask[1] && length $mask[1] ? $mask[1] : '*' )
+  . '@' . (defined $mask[2] && length $mask[2] ? $mask[2] : '*' )
 }
 
 sub parse_user {
